@@ -8,9 +8,9 @@ from reactivex.observable import ConnectableObservable
 from reactivex.disposable import CompositeDisposable
 from reactivex.scheduler import ThreadPoolScheduler
 from elm_framework_helpers.websockets import models
-from bittrade_binance_websocket.events.cancel_order import CancelOrderRequest
 from bittrade_binance_websocket.models import UserFeedMessage
 from bittrade_binance_websocket.models.response_message import SpotResponseMessage
+from bittrade_binance_websocket.models.rest import margin_account
 from bittrade_binance_websocket.models.rest.listen_key import CreateListenKeyResponse
 from bittrade_binance_websocket.models.rest.symbol_price_ticker import SymbolPriceTicker
 from bittrade_binance_websocket.models.order import (
@@ -18,6 +18,8 @@ from bittrade_binance_websocket.models.order import (
     SymbolOrdersCancelRequest,
     PlaceOrderRequest,
     PlaceOrderResponse,
+    MarginSymbolOrdersRequest,
+    SymbolOrderResponseItem,
 )
 
 
@@ -32,6 +34,9 @@ class FrameworkContext:
     exchange: binance
     get_active_listen_key_http: Callable[[], Observable[CreateListenKeyResponse]]
     get_listen_key_http: Callable[[], Observable[CreateListenKeyResponse]]
+    isolated_margin_get_listen_key_http: Callable[
+        [str], Observable[CreateListenKeyResponse]
+    ]
     delete_listen_key_http: Callable[[str], Observable[None]]
     keep_alive_listen_key_http: Callable[[str], Observable[None]]
     market_symbol_price_ticker_http: Callable[[str], Observable[SymbolPriceTicker]]
@@ -42,15 +47,31 @@ class FrameworkContext:
     spot_trade_guaranteed_sockets: models.EnhancedWebsocketBehaviorSubject
     spot_order_create: Callable[[PlaceOrderRequest], Observable[PlaceOrderResponse]]
     spot_order_cancel: Callable[[OrderCancelRequest], Observable[dict]]
+    order_create_http: Callable[[PlaceOrderRequest], Observable[PlaceOrderResponse]]
+    order_cancel_http: Callable[[OrderCancelRequest], Observable[dict]]
     spot_symbol_orders_cancel: Callable[
         [SymbolOrdersCancelRequest], Observable[SpotResponseMessage]
     ]
-    spot_symbol_orders_cancel_http: Callable[
+    symbol_orders_cancel_http: Callable[
         [SymbolOrdersCancelRequest], Observable[SpotResponseMessage]
     ]
-    spot_current_open_orders_http: Callable[
+    current_open_orders_http: Callable[
         [SymbolOrdersCancelRequest], Observable[SpotResponseMessage]
     ]
+    margin_query_cross_margin_account_details_http: Callable[
+        [Optional[bool]], Observable[margin_account.AccountInfo]
+    ]
+    margin_query_margin_fee_data_http: Callable[
+        [str, Optional[bool]], Observable[margin_account.LeverageData]
+    ]
     user_data_stream_sockets: Observable[models.EnhancedWebsocket]
     user_data_stream_socket_bundles: ConnectableObservable[models.WebsocketBundle]
     user_data_stream_messages: Observable[UserFeedMessage]
+    isolated_margin_user_stream_factory: Callable[
+        [str],
+        tuple[
+            ConnectableObservable[models.WebsocketBundle],
+            Observable[models.EnhancedWebsocket],
+            Observable[UserFeedMessage],
+        ],
+    ]
